@@ -8,7 +8,7 @@
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2010 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 
 /**
@@ -18,7 +18,7 @@
  * @package    LetoDMS_Core
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C)2011 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 class LetoDMS_Core_DocumentCategory {
 	/**
@@ -56,7 +56,7 @@ class LetoDMS_Core_DocumentCategory {
 	function setName($newName) {
 		$db = $this->_dms->getDB();
 
-		$queryStr = "UPDATE tblCategory SET name = '$newName' WHERE id = ". $this->_id;
+		$queryStr = "UPDATE tblCategory SET name = ".$db->qstr($newName)." WHERE id = ". $this->_id;
 		if (!$db->getResult($queryStr))
 			return false;
 
@@ -84,7 +84,7 @@ class LetoDMS_Core_DocumentCategory {
 	function addCategory($keywords) {
 		$db = $this->_dms->getDB();
 
-		$queryStr = "INSERT INTO tblCategory (category) VALUES ('".$keywords."')";
+		$queryStr = "INSERT INTO tblCategory (category) VALUES (".$db->qstr($keywords).")";
 		return $db->getResult($queryStr);
 	}
 
