@@ -9,7 +9,7 @@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 
 /**
@@ -19,7 +19,7 @@
  * @package    LetoDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe, 2010 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 class LetoDMS_Core_Group {
 	/**
@@ -61,7 +61,7 @@ class LetoDMS_Core_Group {
 	function setName($newName) { /* {{{ */
 		$db = $this->_dms->getDB();
 
-		$queryStr = "UPDATE tblGroups SET name = '" . $newName . "' WHERE id = " . $this->_id;
+		$queryStr = "UPDATE tblGroups SET name = ".$db->qstr($newName)." WHERE id = " . $this->_id;
 		if (!$db->getResult($queryStr))
 			return false;
 
@@ -74,7 +74,7 @@ class LetoDMS_Core_Group {
 	function setComment($newComment) { /* {{{ */
 		$db = $this->_dms->getDB();
 
-		$queryStr = "UPDATE tblGroups SET comment = '" . $newComment . "' WHERE id = " . $this->_id;
+		$queryStr = "UPDATE tblGroups SET comment = ".$db->qstr($newComment)." WHERE id = " . $this->_id;
 		if (!$db->getResult($queryStr))
 			return false;
 
@@ -103,6 +103,25 @@ class LetoDMS_Core_Group {
 		return $this->_users;
 	} /* }}} */
 
+	function getManagers() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$queryStr = "SELECT `tblUsers`.* FROM `tblUsers` ".
+			"LEFT JOIN `tblGroupMembers` ON `tblGroupMembers`.`userID`=`tblUsers`.`id` ".
+			"WHERE `tblGroupMembers`.`groupID` = '". $this->_id ."' AND tblGroupMembers.manager = 1";
+		$resArr = $db->getResultArray($queryStr);
+		if (is_bool($resArr) && $resArr == false)
+			return false;
+
+		$managers = array();
+
+		foreach ($resArr as $row) {
+			$user = new LetoDMS_Core_User($row["id"], $row["login"], $row["pwd"], $row["fullName"], $row["email"], $row["language"], $row["theme"], $row["comment"], $row["role"], $row['hidden']);
+			array_push($managers, $user);
+		}
+		return $managers;
+	} /* }}} */
+
 	function addUser($user,$asManager=false) { /* {{{ */
 		$db = $this->_dms->getDB();
 
@@ -228,8 +247,8 @@ class LetoDMS_Core_Group {
 			"LEFT JOIN `tblDocumentReviewLog` USING (`reviewID`) ".
 			"LEFT JOIN `ttreviewid` on `ttreviewid`.`maxLogID` = `tblDocumentReviewLog`.`reviewLogID` ".
 			"WHERE `ttreviewid`.`maxLogID`=`tblDocumentReviewLog`.`reviewLogID` ".
-			($documentID==null ? "" : "AND `tblDocumentReviewers`.`documentID` = '". $documentID ."' ").
-			($version==null ? "" : "AND `tblDocumentReviewers`.`version` = '". $version ."' ").
+			($documentID==null ? "" : "AND `tblDocumentReviewers`.`documentID` = '". (int) $documentID ."' ").
+			($version==null ? "" : "AND `tblDocumentReviewers`.`version` = '". (int) $version ."' ").
 			"AND `tblDocumentReviewers`.`type`='1' ".
 			"AND `tblDocumentReviewers`.`required`='". $this->_id ."' ";
 		$resArr = $db->getResultArray($queryStr);
@@ -259,8 +278,8 @@ class LetoDMS_Core_Group {
 			"LEFT JOIN `tblDocumentApproveLog` USING (`approveID`) ".
 			"LEFT JOIN `ttapproveid` on `ttapproveid`.`maxLogID` = `tblDocumentApproveLog`.`approveLogID` ".
 			"WHERE `ttapproveid`.`maxLogID`=`tblDocumentApproveLog`.`approveLogID` ".
-			($documentID==null ? "" : "AND `tblDocumentApprovers`.`documentID` = '". $documentID ."' ").
-			($version==null ? "" : "AND `tblDocumentApprovers`.`version` = '". $version ."' ").
+			($documentID==null ? "" : "AND `tblDocumentApprovers`.`documentID` = '". (int) $documentID ."' ").
+			($version==null ? "" : "AND `tblDocumentApprovers`.`version` = '". (int) $version ."' ").
 			"AND `tblDocumentApprovers`.`type`='1' ".
 			"AND `tblDocumentApprovers`.`required`='". $this->_id ."' ";
 		$resArr = $db->getResultArray($queryStr);
