@@ -9,7 +9,7 @@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 
 /**
@@ -24,9 +24,10 @@ require_once "adodb/adodb.inc.php";
  * @package    LetoDMS_Core
  * @author     Markus Westphal, Malcolm Cowe, Matteo Lucarelli, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe, 2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 class LetoDMS_Core_DatabaseAccess {
+	var $_debug;
 	var $_driver;
 	var $_hostname;
 	var $_database;
@@ -84,6 +85,7 @@ class LetoDMS_Core_DatabaseAccess {
 		$this->_ttapproveid = false;
 		$this->_ttstatid = false;
 		$this->_ttcontentid = false;
+		$this->_debug = false;
 	}
 
 	/**
@@ -101,6 +103,7 @@ class LetoDMS_Core_DatabaseAccess {
 		if (!$this->_conn)
 			return false;
 
+		$this->_conn->SetFetchMode(ADODB_FETCH_ASSOC);
 		$this->_conn->Execute('SET NAMES utf8');
 		$this->_connected = true;
 		return true;
@@ -119,6 +122,17 @@ class LetoDMS_Core_DatabaseAccess {
 		else return true;
 	} /* }}} */
 
+	/**
+	 * Sanitize String used in database operations
+	 *
+	 * @param string text
+	 * @return string sanitized string
+	 */
+	function qstr($text) { /* {{{ */
+		return $this->_conn->qstr($text);
+	} /* }}} */
+
+
 	/**
 	 * Execute SQL query and return result
 	 *
@@ -132,7 +146,8 @@ class LetoDMS_Core_DatabaseAccess {
 		
 		$res = $this->_conn->Execute($queryStr);
 		if (!$res) {
-			print "<br>" . $this->getErrorMsg() . "<br>" . $queryStr . "</br>";
+			if($this->_debug)
+				echo "error: ".$queryStr."<br />";
 			return false;
 		}
 		$resArr = $res->GetArray();
@@ -146,12 +161,16 @@ class LetoDMS_Core_DatabaseAccess {
 	 * Call this function only with sql query which do not return data records.
 	 *
 	 * @param string $queryStr sql query
+	 * @param boolean $silent not used anymore. This was used when this method
+	 *        still issued an error message
 	 * @return boolean true if query could be executed otherwise false
 	 */
 	function getResult($queryStr, $silent=false) { /* {{{ */
 		$res = $this->_conn->Execute($queryStr);
-		if (!$res && !$silent)
-			print "<br>" . $this->getErrorMsg() . "<br>" . $queryStr . "</br>";
+		if(!$res) {
+			if($this->_debug)
+				echo "error: ".$queryStr."<br />";
+		}
 		
 		return $res;
 	} /* }}} */
