@@ -10,7 +10,7 @@
  * @copyright  Copyright (C) 2002-2005 Markus Westphal,
  *             2006-2008 Malcolm Cowe, 2010 Matteo Lucarelli,
  *             2010 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 
 /**
@@ -22,7 +22,7 @@
  * @copyright  Copyright (C) 2002-2005 Markus Westphal,
  *             2006-2008 Malcolm Cowe, 2010 Matteo Lucarelli,
  *             2010 Uwe Steinmann
- * @version    Release: 3.2.1
+ * @version    Release: 3.3.9
  */
 class LetoDMS_Core_File {
 	function renameFile($old, $new) {
@@ -110,7 +110,7 @@ class LetoDMS_Core_File {
 				continue;
 			else if (is_dir($path . $entry))
 			{
-				if (!removeDir($path . $entry . "/"))
+				if (!self::removeDir($path . $entry . "/"))
 					return false;
 			}
 			else
@@ -130,7 +130,7 @@ class LetoDMS_Core_File {
 				if ($entry == ".." || $entry == ".")
 					continue;
 				else if (is_dir($sourcePath . $entry)) {
-					if (!copyDir($sourcePath . $entry . "/", $targetPath . $entry . "/"))
+					if (!self::copyDir($sourcePath . $entry . "/", $targetPath . $entry . "/"))
 						return false;
 				} else {
 					if (!@copy($sourcePath . $entry, $targetPath . $entry))
